@@ -1,4 +1,4 @@
-from typing import Union
+from typing import Optional, Union
 
 from pydantic import BaseModel
 
@@ -11,7 +11,7 @@ AdapterInstance = Union[FileAdapter, MongoAdapter]
 
 class Adapters(BaseModel):
     file: FileAdapter
-    mongo: MongoAdapter
+    mongo: Optional[MongoAdapter]
     current: AdapterInstance
 
     class Config:
@@ -21,8 +21,14 @@ class Adapters(BaseModel):
 def get_adapters() -> Adapters:
     settings = get_settings()
 
-    mongo = MongoAdapter(settings.mongo_settings)
+    mongo = (
+        MongoAdapter(settings.mongo_settings)
+        if settings.mongo_settings.is_valid
+        else None
+    )
     file = FileAdapter(settings.local_store_path)
     file.create()
 
-    return Adapters(mongo=mongo, file=file, current=mongo if mongo.connected else file)
+    return Adapters(
+        mongo=mongo, file=file, current=mongo if mongo and mongo.connected else file
+    )
